pub enum Size {
Medium = 72,
Long = 88,
VeryLong = 103,
}Expand description
Size which can be cast into usize to use as the size of the output byte array e.g.
Example
use cool_id_generator::Size;
const size: usize = Size::Medium as usize;
let byte_array: [u8; size] = [0u8; size];Variants
Medium = 72
The largest size (in bytes) of a Medium ID; 1 billion combinations
Long = 88
The largest size (in bytes) of a Long ID; 115 billion combinations
VeryLong = 103
The largest size (in bytes) of a VeryLong ID; 10^15 combinations (or 2,088,136,477,473,228)